@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KLDAP_LDAPSEARCH_H
-#define KLDAP_LDAPSEARCH_H
+#pragma once
 
 #include <QObject>
 #include <QString>
@@ -132,4 +131,3 @@ private:
 };
 }
 
-#endif
